@@ -21,13 +21,13 @@ from act.plotting import (
 )
 from act.utils.data_utils import accumulate_precip
 
-matplotlib.use('Agg')
 try:
-    import metpy.calc as mpcalc
-
-    METPY = True
+    import cartopy
+    CARTOPY_AVAILABLE = True
 except ImportError:
-    METPY = False
+    CARTOPY_AVAILABLE = False
+
+matplotlib.use('Agg')
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -310,29 +310,25 @@ def test_barb_sounding_plot():
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_skewt_plot():
     sonde_ds = arm.read_netcdf(sample_files.EXAMPLE_SONDE1)
-
-    if METPY:
-        skewt = SkewTDisplay(sonde_ds)
-        skewt.plot_from_u_and_v('u_wind', 'v_wind', 'pres', 'tdry', 'dp')
-        sonde_ds.close()
-        try:
-            return skewt.fig
-        finally:
-            matplotlib.pyplot.close(skewt.fig)
+    skewt = SkewTDisplay(sonde_ds)
+    skewt.plot_from_u_and_v('u_wind', 'v_wind', 'pres', 'tdry', 'dp')
+    sonde_ds.close()
+    try:
+        return skewt.fig
+    finally:
+        matplotlib.pyplot.close(skewt.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_skewt_plot_spd_dir():
     sonde_ds = arm.read_netcdf(sample_files.EXAMPLE_SONDE1)
-
-    if METPY:
-        skewt = SkewTDisplay(sonde_ds, ds_name='act_datastream')
-        skewt.plot_from_spd_and_dir('wspd', 'deg', 'pres', 'tdry', 'dp')
-        sonde_ds.close()
-        try:
-            return skewt.fig
-        finally:
-            matplotlib.pyplot.close(skewt.fig)
+    skewt = SkewTDisplay(sonde_ds, ds_name='act_datastream')
+    skewt.plot_from_spd_and_dir('wspd', 'deg', 'pres', 'tdry', 'dp')
+    sonde_ds.close()
+    try:
+        return skewt.fig
+    finally:
+        matplotlib.pyplot.close(skewt.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=80)
@@ -346,31 +342,30 @@ def test_multi_skewt_plot():
         sonde_ds = sonde_ds.resample(time='30s').nearest()
         test.update({time: sonde_ds})
 
-    if METPY:
-        skewt = SkewTDisplay(test, subplot_shape=(2, 2))
-        i = 0
-        j = 0
-        for f in files:
-            time = f.split('.')[-3]
-            skewt.plot_from_spd_and_dir(
-                'wspd',
-                'deg',
-                'pres',
-                'tdry',
-                'dp',
-                subplot_index=(j, i),
-                dsname=time,
-                p_levels_to_plot=np.arange(10.0, 1000.0, 25),
-            )
-            if j == 1:
-                i += 1
-                j = 0
-            elif j == 0:
-                j += 1
-        try:
-            return skewt.fig
-        finally:
-            matplotlib.pyplot.close(skewt.fig)
+    skewt = SkewTDisplay(test, subplot_shape=(2, 2))
+    i = 0
+    j = 0
+    for f in files:
+        time = f.split('.')[-3]
+        skewt.plot_from_spd_and_dir(
+            'wspd',
+            'deg',
+            'pres',
+            'tdry',
+            'dp',
+            subplot_index=(j, i),
+            dsname=time,
+            p_levels_to_plot=np.arange(10.0, 1000.0, 25),
+        )
+        if j == 1:
+            i += 1
+            j = 0
+        elif j == 0:
+            j += 1
+    try:
+        return skewt.fig
+    finally:
+        matplotlib.pyplot.close(skewt.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=31)
@@ -389,6 +384,7 @@ def test_xsection_plot():
         matplotlib.pyplot.close(xsection.fig)
 
 
+@pytest.mark.skipif(not CARTOPY_AVAILABLE, reason="Cartopy is not installed.")
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_xsection_plot_map():
     radar_ds = arm.read_netcdf(sample_files.EXAMPLE_VISST, combine='nested', concat_dim='time')
@@ -414,6 +410,7 @@ def test_xsection_plot_map():
         pass
 
 
+@pytest.mark.skipif(not CARTOPY_AVAILABLE, reason="Cartopy is not installed.")
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_geoplot():
     sonde_ds = arm.read_netcdf(sample_files.EXAMPLE_SONDE1)
