@@ -7,7 +7,7 @@ import lazy_loader as lazy
 
 __getattr__, __dir__, __all__ = lazy.attach(
     __name__,
-    submodules=['ship_utils'],
+    submodules=['data_utils', 'datetime_utils', 'geo_utils', 'inst_utils', 'io_utils', 'qc_utils', 'radiance_utils', 'ship_utils'],
     submod_attrs={
         'data_utils': [
             'ChangeUnits',
@@ -33,6 +33,9 @@ __getattr__, __dir__, __all__ = lazy.attach(
         'geo_utils': [
             'add_solar_variable',
             'destination_azimuth_distance',
+            'get_solar_azimuth_elevation',
+            'get_sunrise_sunset_noon',
+            'is_sun_visible',
         ],
         'inst_utils': ['decode_present_weather'],
         'qc_utils': ['calculate_dqr_times'],
